@@ -133,8 +133,9 @@ struct rule {
 static long		detzcode(const char * codep);
 static time_t		detzcode64(const char * codep);
 static int		differ_by_repeat(time_t t1, time_t t0);
-static const char *	getzname(const char * strp);
-static const char *	getqzname(const char * strp, const int delim);
+static const char *	getzname(const char * strp) ATTRIBUTE_PURE;
+static const char *	getqzname(const char * strp, const int delim)
+  ATTRIBUTE_PURE;
 static const char *	getnum(const char * strp, int * nump, int min,
 				int max);
 static const char *	getsecs(const char * strp, long * secsp);
@@ -146,7 +147,7 @@ static struct tm *	gmtsub(const time_t * timep, long offset,
 static struct tm *	localsub(const time_t * timep, long offset,
 				struct tm * tmp);
 static int		increment_overflow(int * number, int delta);
-static int		leaps_thru_end_of(int y);
+static int		leaps_thru_end_of(int y) ATTRIBUTE_PURE;
 static int		long_increment_overflow(long * number, int delta);
 static int		long_normalize_overflow(long * tensptr,
 				int * unitsptr, int base);
@@ -170,7 +171,8 @@ static struct tm *	timesub(const time_t * timep, long offset,
 static int		tmcomp(const struct tm * atmp,
 				const struct tm * btmp);
 static time_t		transtime(time_t janfirst, int year,
-				const struct rule * rulep, long offset);
+				  const struct rule * rulep, long offset)
+  ATTRIBUTE_PURE;
 static int		typesequiv(const struct state * sp, int a, int b);
 static int		tzload(const char * name, struct state * sp,
 				int doextend);
@@ -222,8 +224,7 @@ time_t			altzone = 0;
 #endif /* defined ALTZONE */
 
 static long
-detzcode(codep)
-const char * const	codep;
+detzcode(const char *const codep)
 {
 	register long	result;
 	register int	i;
@@ -235,8 +236,7 @@ const char * const	codep;
 }
 
 static time_t
-detzcode64(codep)
-const char * const	codep;
+detzcode64(const char *const codep)
 {
 	register time_t	result;
 	register int	i;
@@ -310,9 +310,7 @@ settzname(void)
 }
 
 static int
-differ_by_repeat(t1, t0)
-const time_t	t1;
-const time_t	t0;
+differ_by_repeat(const time_t t1, const time_t t0)
 {
 	if (TYPE_INTEGRAL(time_t) &&
 		TYPE_BIT(time_t) - TYPE_SIGNED(time_t) < SECSPERREPEAT_BITS)
@@ -321,10 +319,8 @@ const time_t	t0;
 }
 
 static int
-tzload(name, sp, doextend)
-register const char *		name;
-register struct state * const	sp;
-register const int		doextend;
+tzload(register const char *name, register struct state *const sp,
+       register const int doextend)
 {
 	register const char *		p;
 	register int			i;
@@ -571,21 +567,18 @@ register const int		doextend;
 		}
 	}
 #ifdef ALL_STATE
-	(void) free((void *) up);
+	free(up);
 #endif /* defined ALL_STATE */
 	return 0;
 oops:
 #ifdef ALL_STATE
-	(void) free((void *) up);
+	free(up);
 #endif /* defined ALL_STATE */
 	return -1;
 }
 
 static int
-typesequiv(sp, a, b)
-const struct state * const	sp;
-const int			a;
-const int			b;
+typesequiv(const struct state *const sp, const int a, const int b)
 {
 	register int	result;
 
@@ -622,8 +615,7 @@ static const int	year_lengths[2] = {
 */
 
 static const char *
-getzname(strp)
-register const char *	strp;
+getzname(register const char *strp)
 {
 	register char	c;
 
@@ -660,11 +652,7 @@ getqzname(register const char *strp, const int delim)
 */
 
 static const char *
-getnum(strp, nump, min, max)
-register const char *	strp;
-int * const		nump;
-const int		min;
-const int		max;
+getnum(register const char *strp, int *const nump, const int min, const int max)
 {
 	register char	c;
 	register int	num;
@@ -693,9 +681,7 @@ const int		max;
 */
 
 static const char *
-getsecs(strp, secsp)
-register const char *	strp;
-long * const		secsp;
+getsecs(register const char *strp, long *const secsp)
 {
 	int	num;
 
@@ -735,9 +721,7 @@ long * const		secsp;
 */
 
 static const char *
-getoffset(strp, offsetp)
-register const char *	strp;
-long * const		offsetp;
+getoffset(register const char *strp, long *const offsetp)
 {
 	register int	neg = 0;
 
@@ -762,9 +746,7 @@ long * const		offsetp;
 */
 
 static const char *
-getrule(strp, rulep)
-const char *			strp;
-register struct rule * const	rulep;
+getrule(const char *strp, register struct rule *const rulep)
 {
 	if (*strp == 'J') {
 		/*
@@ -816,11 +798,8 @@ register struct rule * const	rulep;
 */
 
 static time_t
-transtime(janfirst, year, rulep, offset)
-const time_t				janfirst;
-const int				year;
-register const struct rule * const	rulep;
-const long				offset;
+transtime(const time_t janfirst, const int year,
+	  register const struct rule *const rulep, const long offset)
 {
 	register int	leapyear;
 	register time_t	value;
@@ -911,10 +890,8 @@ const long				offset;
 */
 
 static int
-tzparse(name, sp, lastditch)
-const char *			name;
-register struct state * const	sp;
-const int			lastditch;
+tzparse(const char *name, register struct state *const sp,
+	const int lastditch)
 {
 	const char *			stdname;
 	const char *			dstname;
@@ -1149,8 +1126,7 @@ const int			lastditch;
 }
 
 static void
-gmtload(sp)
-struct state * const	sp;
+gmtload(struct state *const sp)
 {
 	if (tzload(gmt, sp, TRUE) != 0)
 		(void) tzparse(gmt, sp, TRUE);
@@ -1172,14 +1148,14 @@ tzsetwall(void)
 
 #ifdef ALL_STATE
 	if (lclptr == NULL) {
-		lclptr = (struct state *) calloc(1, sizeof *lclptr);
+		lclptr = calloc(1, sizeof *lclptr);
 		if (lclptr == NULL) {
 			settzname();	/* all we can do */
 			return;
 		}
 	}
 #endif /* defined ALL_STATE */
-	if (tzload((char *) NULL, lclptr, TRUE) != 0)
+	if (tzload(NULL, lclptr, TRUE) != 0)
 		gmtload(lclptr);
 	settzname();
 }
@@ -1203,7 +1179,7 @@ tzset(void)
 
 #ifdef ALL_STATE
 	if (lclptr == NULL) {
-		lclptr = (struct state *) calloc(1, sizeof *lclptr);
+		lclptr = calloc(1, sizeof *lclptr);
 		if (lclptr == NULL) {
 			settzname();	/* all we can do */
 			return;
@@ -1238,10 +1214,7 @@ tzset(void)
 
 /*ARGSUSED*/
 static struct tm *
-localsub(timep, offset, tmp)
-const time_t * const	timep;
-const long		offset;
-struct tm * const	tmp;
+localsub(const time_t *const timep, const long offset, struct tm *const tmp)
 {
 	register struct state *		sp;
 	register const struct ttinfo *	ttisp;
@@ -1330,8 +1303,7 @@ struct tm * const	tmp;
 }
 
 struct tm *
-localtime(timep)
-const time_t * const	timep;
+localtime(const time_t *const timep)
 {
 	tzset();
 	return localsub(timep, 0L, &tm);
@@ -1342,9 +1314,7 @@ const time_t * const	timep;
 */
 
 struct tm *
-localtime_r(timep, tmp)
-const time_t * const	timep;
-struct tm *		tmp;
+localtime_r(const time_t *const timep, struct tm *tmp)
 {
 	return localsub(timep, 0L, tmp);
 }
@@ -1354,17 +1324,14 @@ struct tm *		tmp;
 */
 
 static struct tm *
-gmtsub(timep, offset, tmp)
-const time_t * const	timep;
-const long		offset;
-struct tm * const	tmp;
+gmtsub(const time_t *const timep, const long offset, struct tm *const tmp)
 {
 	register struct tm *	result;
 
 	if (!gmt_is_set) {
 		gmt_is_set = TRUE;
 #ifdef ALL_STATE
-		gmtptr = (struct state *) calloc(1, sizeof *gmtptr);
+		gmtptr = calloc(1, sizeof *gmtptr);
 		if (gmtptr != NULL)
 #endif /* defined ALL_STATE */
 			gmtload(gmtptr);
@@ -1393,8 +1360,7 @@ struct tm * const	tmp;
 }
 
 struct tm *
-gmtime(timep)
-const time_t * const	timep;
+gmtime(const time_t *const timep)
 {
 	return gmtsub(timep, 0L, &tm);
 }
@@ -1404,9 +1370,7 @@ const time_t * const	timep;
 */
 
 struct tm *
-gmtime_r(timep, tmp)
-const time_t * const	timep;
-struct tm *		tmp;
+gmtime_r(const time_t *const timep, struct tm *tmp)
 {
 	return gmtsub(timep, 0L, tmp);
 }
@@ -1414,9 +1378,7 @@ struct tm *		tmp;
 #ifdef STD_INSPIRED
 
 struct tm *
-offtime(timep, offset)
-const time_t * const	timep;
-const long		offset;
+offtime(const time_t *const timep, const long offset)
 {
 	return gmtsub(timep, offset, &tm);
 }
@@ -1429,19 +1391,16 @@ const long		offset;
 */
 
 static int
-leaps_thru_end_of(y)
-register const int	y;
+leaps_thru_end_of(register const int y)
 {
 	return (y >= 0) ? (y / 4 - y / 100 + y / 400) :
 		-(leaps_thru_end_of(-(y + 1)) + 1);
 }
 
 static struct tm *
-timesub(timep, offset, sp, tmp)
-const time_t * const			timep;
-const long				offset;
-register const struct state * const	sp;
-register struct tm * const		tmp;
+timesub(const time_t *const timep, const long offset,
+	register const struct state *const sp,
+	register struct tm *const tmp)
 {
 	register const struct lsinfo *	lp;
 	register time_t			tdays;
@@ -1571,8 +1530,7 @@ register struct tm * const		tmp;
 }
 
 char *
-ctime(timep)
-const time_t * const	timep;
+ctime(const time_t *const timep)
 {
 /*
 ** Section 4.12.3.2 of X3.159-1989 requires that
@@ -1584,9 +1542,7 @@ const time_t * const	timep;
 }
 
 char *
-ctime_r(timep, buf)
-const time_t * const	timep;
-char *			buf;
+ctime_r(const time_t *const timep, char *buf)
 {
 	struct tm	mytm;
 
@@ -1611,9 +1567,7 @@ char *			buf;
 */
 
 static int
-increment_overflow(ip, j)
-int * const	ip;
-int		j;
+increment_overflow(int *const ip, int j)
 {
 	register int const	i = *ip;
 
@@ -1630,9 +1584,7 @@ int		j;
 }
 
 static int
-long_increment_overflow(lp, m)
-long * const	lp;
-int const	m;
+long_increment_overflow(long *const lp, int const m)
 {
 	register long const	l = *lp;
 
@@ -1643,10 +1595,7 @@ int const	m;
 }
 
 static int
-normalize_overflow(tensptr, unitsptr, base)
-int * const	tensptr;
-int * const	unitsptr;
-const int	base;
+normalize_overflow(int *const tensptr, int *const unitsptr, const int base)
 {
 	register int	tensdelta;
 
@@ -1658,10 +1607,7 @@ const int	base;
 }
 
 static int
-long_normalize_overflow(tensptr, unitsptr, base)
-long * const	tensptr;
-int * const	unitsptr;
-const int	base;
+long_normalize_overflow(long *const tensptr, int *const unitsptr, const int base)
 {
 	register int	tensdelta;
 
@@ -1673,9 +1619,8 @@ const int	base;
 }
 
 static int
-tmcomp(atmp, btmp)
-register const struct tm * const atmp;
-register const struct tm * const btmp;
+tmcomp(register const struct tm *const atmp,
+       register const struct tm *const btmp)
 {
 	register int	result;
 
@@ -1689,12 +1634,11 @@ register const struct tm * const btmp;
 }
 
 static time_t
-time2sub(tmp, funcp, offset, okayp, do_norm_secs)
-struct tm * const	tmp;
-struct tm * (* const	funcp)(const time_t*, long, struct tm*);
-const long		offset;
-int * const		okayp;
-const int		do_norm_secs;
+time2sub(struct tm *const tmp,
+	 struct tm *(*const funcp)(const time_t *, long, struct tm *),
+	 const long offset,
+	 int *const okayp,
+	 const int do_norm_secs)
 {
 	register const struct state *	sp;
 	register int			dir;
@@ -1873,11 +1817,10 @@ label:
 }
 
 static time_t
-time2(tmp, funcp, offset, okayp)
-struct tm * const	tmp;
-struct tm * (* const	funcp)(const time_t*, long, struct tm*);
-const long		offset;
-int * const		okayp;
+time2(struct tm * const	tmp,
+      struct tm * (*const funcp)(const time_t *, long, struct tm *),
+      const long offset,
+      int *const okayp)
 {
 	time_t	t;
 
@@ -1891,10 +1834,9 @@ int * const		okayp;
 }
 
 static time_t
-time1(tmp, funcp, offset)
-struct tm * const	tmp;
-struct tm * (* const	funcp)(const time_t *, long, struct tm *);
-const long		offset;
+time1(struct tm *const tmp,
+      struct tm *(*const funcp) (const time_t *, long, struct tm *),
+      const long offset)
 {
 	register time_t			t;
 	register const struct state *	sp;
@@ -1968,8 +1910,7 @@ const long		offset;
 }
 
 time_t
-mktime(tmp)
-struct tm * const	tmp;
+mktime(struct tm *const tmp)
 {
 	tzset();
 	return time1(tmp, localsub, 0L);
@@ -1978,8 +1919,7 @@ struct tm * const	tmp;
 #ifdef STD_INSPIRED
 
 time_t
-timelocal(tmp)
-struct tm * const	tmp;
+timelocal(struct tm *const tmp)
 {
 	if (tmp != NULL)
 		tmp->tm_isdst = -1;	/* in case it wasn't initialized */
@@ -1987,8 +1927,7 @@ struct tm * const	tmp;
 }
 
 time_t
-timegm(tmp)
-struct tm * const	tmp;
+timegm(struct tm *const tmp)
 {
 	if (tmp != NULL)
 		tmp->tm_isdst = 0;
@@ -1996,9 +1935,7 @@ struct tm * const	tmp;
 }
 
 time_t
-timeoff(tmp, offset)
-struct tm * const	tmp;
-const long		offset;
+timeoff(struct tm *const tmp, const long offset)
 {
 	if (tmp != NULL)
 		tmp->tm_isdst = 0;
@@ -2015,8 +1952,7 @@ const long		offset;
 */
 
 long
-gtime(tmp)
-struct tm * const	tmp;
+gtime(struct tm *const tmp)
 {
 	const time_t	t = mktime(tmp);
 
@@ -2042,8 +1978,7 @@ struct tm * const	tmp;
 */
 
 static long
-leapcorr(timep)
-time_t *	timep;
+leapcorr(time_t *timep)
 {
 	register struct state *		sp;
 	register struct lsinfo *	lp;
@@ -2060,16 +1995,14 @@ time_t *	timep;
 }
 
 time_t
-time2posix(t)
-time_t	t;
+time2posix(time_t t)
 {
 	tzset();
 	return t - leapcorr(&t);
 }
 
 time_t
-posix2time(t)
-time_t	t;
+posix2time(time_t t)
 {
 	time_t	x;
 	time_t	y;
